@@ -9,7 +9,7 @@ use File::Basename;
 use File::Spec::Functions qw(rel2abs);
 use Serge::Util qw(subst_macros);
 
-our $VERSION = "0.0.2";
+our $VERSION = "0.0.3";
 
 sub name {
     return
@@ -26,6 +26,7 @@ sub init {
             project_id => 'STRING',
             token_id   => 'STRING',
             token      => 'STRING',
+            project_translation_files_path => 'STRING',
             push       => {
                 disassemble_algorithm_name => 'STRING',
             },
@@ -48,28 +49,38 @@ sub validate_data {
     $self->SUPER::validate_data;
 
     $self->{data}->{filetype} = subst_macros( $self->{data}->{filetype} );
+    $self->{data}->{project_translation_files_path} = subst_macros( $self->{data}->{project_translation_files_path} );
 
-    my %job_ts_file_paths;
-    $job_ts_file_paths{ $_->{ts_file_path} }++
-      for @{ $self->{parent}{config}{data}{jobs} };
-    my @job_ts_file_paths = keys %job_ts_file_paths;
-    die sprintf( "More than one 'ts_file_path' found in the config file: %s" %
-          join( ', ', map { "'$_'" } @job_ts_file_paths ) )
-      if @job_ts_file_paths > 1;
-    my $ts_file_path = shift @job_ts_file_paths;
-    die sprintf(
-"'ts_file_path' which is set to '%s', doesn't match '%LOCALE%/%FILE%' pattern."
-          % $ts_file_path )
-      unless $ts_file_path =~
-      m/(%LOCALE%|%LANG%)\/%FILE%$self->{data}->{filetype}/;
+    unless ( $self->{data}->{project_translation_files_path} ) {
+        my %job_ts_file_paths;
+        $job_ts_file_paths{ $_->{ts_file_path} }++
+          for @{ $self->{parent}{config}{data}{jobs} };
+        my @job_ts_file_paths = keys %job_ts_file_paths;
+        die sprintf( "Set 'project_translation_files_path' parameter, more than one 'ts_file_path' found in the config file: %s",
+              join( ', ', map { "'$_'" } @job_ts_file_paths ) )
+          if @job_ts_file_paths > 1;
+        my $ts_file_path = shift @job_ts_file_paths;
 
-    $self->{data}->{project_translation_files_path} =
-      dirname( dirname($ts_file_path) );
+        die sprintf(
+    "'ts_file_path' which is set to '%s', doesn't match '%%LANG%%' pattern.",
+              $ts_file_path )
+          unless $ts_file_path =~
+          m/(%LOCALE%|%LANG%).*$self->{data}->{filetype}/;
+
+        $self->{data}->{project_translation_files_path} =
+          dirname( dirname($ts_file_path) );
+
+        die sprintf(
+    "'ts_file_path' parent directory, which is set to '%s', does not point to a valid directory. Run 'localize' to generate translation files.",
+            $self->{data}->{project_translation_files_path} )
+          unless -d $self->{data}->{project_translation_files_path};
+    } else {
+        die sprintf(
+    "'project_translation_files_path', which is set to '%s', does not point to a valid directory. Run 'localize' to generate translation files.",
+            $self->{data}->{project_translation_files_path} )
+          unless -d $self->{data}->{project_translation_files_path};
+    }
 
-    die sprintf(
-"'ts_file_path' parent directory, which is set to '%s', does not point to a valid directory. Run 'localize' to generate translation files.",
-        $self->{data}->{project_translation_files_path} )
-      unless -d $self->{data}->{project_translation_files_path};
 
     $self->{data}->{project_id} = subst_macros( $self->{data}->{project_id} );
     $self->{data}->{token_id}   = subst_macros( $self->{data}->{token_id} );
